@@ -1,3 +1,8 @@
+"""
+Virtual environments in the traditional sense are built as reference to the host python. This file allows declarative
+references to elements on the file system, allowing our system to automatically detect what modes it can support given
+the constraints: e.g. can the file system symlink, can the files be read, executed, etc.
+"""
 from __future__ import absolute_import, unicode_literals
 
 import os
@@ -14,15 +19,21 @@ from virtualenv.util.six import ensure_text
 
 @add_metaclass(ABCMeta)
 class PathRef(object):
+    """Base class that checks if a file reference can be symlink/copied"""
+
     FS_SUPPORTS_SYMLINK = fs_supports_symlink()
     FS_CASE_SENSITIVE = fs_is_case_sensitive()
 
-    def __init__(self, src):
+    def __init__(self, src, must_symlink, must_copy):
+        self.must_symlink = must_symlink
+        self.must_copy = must_copy
         self.src = src
         self.exists = src.exists()
         self._can_read = None if self.exists else False
         self._can_copy = None if self.exists else False
         self._can_symlink = None if self.exists else False
+        if self.must_copy is True and self.must_symlink is True:
+            raise ValueError("can copy and symlink at the same time")
 
     def __repr__(self):
         return "{}(src={})".format(self.__class__.__name__, self.src)
@@ -43,24 +54,39 @@ class PathRef(object):
     @property
     def can_copy(self):
         if self._can_copy is None:
-            self._can_copy = self.can_read
+            if self.must_symlink:
+                self._can_copy = self.can_symlink
+            else:
+                self._can_copy = self.can_read
         return self._can_copy
 
     @property
     def can_symlink(self):
         if self._can_symlink is None:
-            self._can_symlink = self.FS_SUPPORTS_SYMLINK and self.can_read
+            if self.must_copy:
+                self._can_symlink = self.can_copy
+            else:
+                self._can_symlink = self.FS_SUPPORTS_SYMLINK and self.can_read
         return self._can_symlink
 
     @abstractmethod
     def run(self, creator, symlinks):
         raise NotImplementedError
 
+    def method(self, symlinks):
+        if self.must_symlink:
+            return symlink
+        if self.must_copy:
+            return copy
+        return symlink if symlinks else copy
+
 
 @add_metaclass(ABCMeta)
 class ExePathRef(PathRef):
-    def __init__(self, src):
-        super(ExePathRef, self).__init__(src)
+    """Base class that checks if a executable can be references via symlink/copy"""
+
+    def __init__(self, src, must_symlink, must_copy):
+        super(ExePathRef, self).__init__(src, must_symlink, must_copy)
         self._can_run = None
 
     @property
@@ -83,22 +109,26 @@ class ExePathRef(PathRef):
 
 
 class PathRefToDest(PathRef):
-    def __init__(self, src, dest):
-        super(PathRefToDest, self).__init__(src)
+    """Link a path on the file system"""
+
+    def __init__(self, src, dest, must_symlink=False, must_copy=False):
+        super(PathRefToDest, self).__init__(src, must_symlink, must_copy)
         self.dest = dest
 
     def run(self, creator, symlinks):
         dest = self.dest(creator, self.src)
-        method = symlink if symlinks else copy
+        method = self.method(symlinks)
         dest_iterable = dest if isinstance(dest, list) else (dest,)
         for dst in dest_iterable:
             method(self.src, dst)
 
 
 class ExePathRefToDest(PathRefToDest, ExePathRef):
-    def __init__(self, src, targets, dest, must_copy=False):
-        ExePathRef.__init__(self, src)
-        PathRefToDest.__init__(self, src, dest)
+    """Link a exe path on the file system"""
+
+    def __init__(self, src, targets, dest, must_symlink=False, must_copy=False):
+        ExePathRef.__init__(self, src, must_symlink, must_copy)
+        PathRefToDest.__init__(self, src, dest, must_symlink, must_copy)
         if not self.FS_CASE_SENSITIVE:
             targets = list(OrderedDict((i.lower(), None) for i in targets).keys())
         self.base = targets[0]
@@ -108,8 +138,8 @@ class ExePathRefToDest(PathRefToDest, ExePathRef):
 
     def run(self, creator, symlinks):
         bin_dir = self.dest(creator, self.src).parent
-        method = symlink if self.must_copy is False and symlinks else copy
         dest = bin_dir / self.base
+        method = self.method(symlinks)
         method(self.src, dest)
         make_exe(dest)
         for extra in self.aliases:
