@@ -38,9 +38,9 @@ class Venv(ViaGlobalRefApi):
             self.create_inline()
         else:
             self.create_via_sub_process()
-            # TODO: cleanup activation scripts
         for lib in self.libs:
             ensure_dir(lib)
+        super(Venv, self).create()
 
     def create_inline(self):
         from venv import EnvBuilder
