@@ -86,12 +86,12 @@ class PythonInfo(object):
             self.sysconfig_vars[u"implementation_lower"] = u"python"
 
         self.distutils_install = {u(k): u(v) for k, v in self._distutils_install().items()}
-        self.system_stdlib = self.sysconfig_path(
-            "stdlib",
-            {k: (self.system_prefix if v.startswith(self.prefix) else v) for k, v in self.sysconfig_vars.items()},
-        )
+        confs = {k: (self.system_prefix if v.startswith(self.prefix) else v) for k, v in self.sysconfig_vars.items()}
+        self.system_stdlib = self.sysconfig_path("stdlib", confs)
+        self.system_stdlib_platform = self.sysconfig_path("platstdlib", confs)
         self.max_size = getattr(sys, "maxsize", getattr(sys, "maxint", None))
         self._creators = None
+        self._stdlib_paths = None
 
     def _fast_get_system_executable(self):
         """Try to get the system executable by just looking at properties"""
@@ -111,10 +111,9 @@ class PythonInfo(object):
     @staticmethod
     def _distutils_install():
         # follow https://github.com/pypa/pip/blob/master/src/pip/_internal/locations.py#L95
-        d = Distribution({"script_args": "--no-user-cfg"})
-        d.parse_config_files()
+        d = Distribution({"script_args": "--no-user-cfg"})  # configuration files not parsed so they do not hijack paths
         i = d.get_command_obj("install", create=True)
-        i.prefix = "a"
+        i.prefix = os.sep  # paths generated are relative to prefix that contains the path sep, this makes it relative
         i.finalize_options()
         result = {key: (getattr(i, "install_{}".format(key))[1:]).lstrip(os.sep) for key in SCHEME_KEYS}
         return result
@@ -277,7 +276,7 @@ class PythonInfo(object):
         return json.dumps(self._to_dict(), indent=2)
 
     def _to_dict(self):
-        data = {var: (getattr(self, var) if var not in ("_creators",) else None) for var in vars(self)}
+        data = {var: (getattr(self, var) if var not in ("_creators", "_stdlib_paths") else None) for var in vars(self)}
         # noinspection PyProtectedMember
         data["version_info"] = data["version_info"]._asdict()  # namedtuple to dictionary
         return data
@@ -452,6 +451,19 @@ class PythonInfo(object):
                 if upper != base:
                     yield upper
 
+    def stdlib_path(self, name):
+        if self._stdlib_paths is None:
+            from collections import OrderedDict
+            from virtualenv.util.path import Path
+
+            pat = OrderedDict((Path(i), None) for i in (self.system_stdlib, self.system_stdlib_platform))
+            self._stdlib_paths = list(pat.keys())
+        for path in self._stdlib_paths:
+            std_path = path / name
+            if std_path.exists():
+                return std_path
+        return self._stdlib_paths[0] / name
+
 
 if __name__ == "__main__":
     # dump a JSON representation of the current python
