@@ -3,20 +3,25 @@ from __future__ import absolute_import, unicode_literals
 import logging
 import os
 import re
-import shutil
 import zipfile
 from abc import ABCMeta, abstractmethod
+from contextlib import contextmanager
 from tempfile import mkdtemp
+from threading import Lock
 
+# noinspection PyProtectedMember
+from distlib.scripts import ScriptMaker, _enquote_executable
 from six import PY3, add_metaclass
 
 from virtualenv.util import ConfigParser
-from virtualenv.util.path import Path
+from virtualenv.util.path import Path, safe_delete
 from virtualenv.util.six import ensure_text
 
 
 @add_metaclass(ABCMeta)
 class PipInstall(object):
+    lock = Lock()
+
     def __init__(self, wheel, creator, image_folder):
         self._wheel = wheel
         self._creator = creator
@@ -29,14 +34,14 @@ class PipInstall(object):
     def _sync(self, src, dst):
         raise NotImplementedError
 
-    def install(self):
+    def install(self, version_info):
         self._extracted = True
         # sync image
         for filename in self._image_dir.iterdir():
             into = self._creator.purelib / filename.name
             if into.exists():
                 if into.is_dir() and not into.is_symlink():
-                    shutil.rmtree(str(into))
+                    safe_delete(into)
                 else:
                     into.unlink()
             self._sync(filename, into)
@@ -44,7 +49,7 @@ class PipInstall(object):
         consoles = set()
         script_dir = self._creator.script_dir
         for name, module in self._console_scripts.items():
-            consoles.update(self._create_console_entry_point(name, module, script_dir))
+            consoles.update(self._create_console_entry_point(name, module, script_dir, version_info))
         logging.debug("generated console scripts %s", " ".join(i.name for i in consoles))
 
     def build_image(self):
@@ -77,13 +82,14 @@ class PipInstall(object):
         try:
             to_folder = Path(folder)
             rel = os.path.relpath(ensure_text(str(self._creator.script_dir)), ensure_text(str(self._creator.purelib)))
+            version_info = self._creator.interpreter.version_info
             for name, module in self._console_scripts.items():
                 new_files.update(
                     Path(os.path.normpath(ensure_text(str(self._image_dir / rel / i.name))))
-                    for i in self._create_console_entry_point(name, module, to_folder)
+                    for i in self._create_console_entry_point(name, module, to_folder, version_info)
                 )
         finally:
-            shutil.rmtree(folder, ignore_errors=True)
+            safe_delete(folder)
         return new_files
 
     @property
@@ -123,23 +129,47 @@ class PipInstall(object):
                         self._console_entry_points[name] = value
         return self._console_entry_points
 
-    def _create_console_entry_point(self, name, value, to_folder):
+    def _create_console_entry_point(self, name, value, to_folder, version_info):
         result = []
-        from distlib.scripts import ScriptMaker
-
         maker = ScriptMaker(None, str(to_folder))
         maker.clobber = True  # overwrite
-        maker.variants = {"", "X", "X.Y"}  # create all variants
+        maker.variants = {""}  # set within patch_distlib_correct_variants
         maker.set_mode = True  # ensure they are executable
-        maker.executable = str(self._creator.exe)
+        # calling private until https://bitbucket.org/pypa/distlib/issues/135/expose-_enquote_executable-as-public
+        maker.executable = _enquote_executable(str(self._creator.exe))
         specification = "{} = {}".format(name, value)
-        new_files = maker.make(specification)
+        with self.patch_distlib_correct_variants(version_info, maker):
+            new_files = maker.make(specification)
         result.extend(Path(i) for i in new_files)
         return result
 
+    @contextmanager
+    def patch_distlib_correct_variants(self, version_info, maker):
+        """
+        Patch until upstream distutils supports creating scripts with different python target
+        https://bitbucket.org/pypa/distlib/issues/134/allow-specifying-the-version-information
+        """
+
+        def _write_script(scriptnames, shebang, script, filenames, ext):
+            name = next(iter(scriptnames))
+            scriptnames = {  # add our variants '', 'X', '-X.Y'
+                name,
+                "{}{}".format(name, version_info.major),
+                "{}-{}.{}".format(name, version_info.major, version_info.minor),
+            }
+            return previous(scriptnames, shebang, script, filenames, ext)
+
+        previous = maker._write_script
+        with self.lock:
+            maker._write_script = _write_script
+            try:
+                yield
+            finally:
+                maker._write_script = previous
+
     def clear(self):
         if self._image_dir.exists():
-            shutil.rmtree(ensure_text(str(self._image_dir)))
+            safe_delete(self._image_dir)
 
     def has_image(self):
         return self._image_dir.exists() and next(self._image_dir.iterdir()) is not None
