@@ -21,7 +21,7 @@ from virtualenv.__main__ import run, run_with_catch
 from virtualenv.create.creator import DEBUG_SCRIPT, Creator, get_env_debug_info
 from virtualenv.discovery.builtin import get_interpreter
 from virtualenv.discovery.py_info import PythonInfo
-from virtualenv.info import IS_PYPY, PY3, fs_is_case_sensitive, fs_supports_symlink
+from virtualenv.info import IS_PYPY, IS_WIN, PY3, fs_is_case_sensitive, fs_supports_symlink
 from virtualenv.pyenv_cfg import PyEnvCfg
 from virtualenv.run import cli_run, session_via_cli
 from virtualenv.util.path import Path
@@ -201,6 +201,11 @@ def test_create_no_seed(python, creator, isolated, system, coverage_env, special
         # option 3: an absolute symlink, should point outside the venv
         assert not link.startswith(str(result.creator.dest))
 
+    if IS_WIN and CURRENT.implementation == "CPython":
+        python_w = result.creator.exe.parent / "pythonw.exe"
+        assert python_w.exists()
+        assert python_w.read_bytes() != result.creator.exe.read_bytes()
+
 
 @pytest.mark.skipif(not CURRENT.has_venv, reason="requires interpreter with venv")
 def test_venv_fails_not_inline(tmp_path, capsys, mocker):
@@ -364,11 +369,17 @@ def test_create_distutils_cfg(creator, tmp_path, monkeypatch):
     setup_cfg = dest / "setup.cfg"
     conf = dedent(
         """
-    [install]
-    prefix={}/a
-    install_scripts={}/b
-    """
-    ).format(tmp_path, tmp_path)
+            [install]
+            prefix={0}{1}prefix
+            install_purelib={0}{1}purelib
+            install_platlib={0}{1}platlib
+            install_headers={0}{1}headers
+            install_scripts={0}{1}scripts
+            install_data={0}{1}data
+            """.format(
+            tmp_path, os.sep
+        )
+    )
     setup_cfg.write_text(setup_cfg.read_text() + conf)
 
     monkeypatch.chdir(dest)  # distutils will read the setup.cfg from the cwd, so change to that
